#!/bin/sh

BIN=/disk/RIST
. /flash/qvidium/inputs.conf
PROGRAM=RISTTx
[ "$QVDEC_BOARD" = true ] && PROGRAM=RISTRx

start_tx() {
  otherArgs='--restampRTP'
  if [ "$DST_PORT" = 5325 ] ; then
      eval `nat_main -l ron -r john -s $DST_PORT`
      if [ "$RemoteExternalPort" != "" ] ; then
          DST_IP_ADDR=$RemoteExternalIP
          DST_PORT=$RemoteExternalPort
          otherArgs="$otherArgs --rtcpPort $ExternalPort"
      fi
  fi

  RISTTx --dstIpAddr $DST_IP_ADDR \
         --dstPort $DST_PORT \
         --srcPort $SRC_PORT \
         --cmdPort $CMD_PORT $otherArgs > /var/log/RISTTx.log 2>&1 &
}

start_rx() {
  otherArgs=
  [ "$USE_RANGE" = true ] && otherArgs=--useRange
  if [ "$SRC_PORT" = 4325 ] ; then
      eval `nat_main -l john -r ron -s $SRC_PORT`
      if [ "$RemoteExternalPort" != "" ] ; then
          otherArgs="$otherArgs --rtcpPort $RemoteExternalPort"
      fi
  fi

  RISTRx --dstIpAddr $DST_IP_ADDR \
         --dstPort $DST_PORT \
         --srcPort $SRC_PORT \
         --delayReorder $DELAY_REORDER \
         --periodRetrans $PERIOD_RETRANS \
         --delayRetrans $DELAY_RETRANS \
         --cmdPort $CMD_PORT \
         $otherArgs > /var/log/RISTRx.log 2>&1 &
}

stop_tx() {
  killall -9 $PROGRAM
}

stop_rx() {
  killall -9 $PROGRAM
}

reset_proxy() {
    $BIN/getstats.sh xmlreset
}

proxy_running() {
    pidof $PROGRAM > /dev/null
    exit $?
}

case "$1" in
  start)
    if ! pidof $PROGRAM > /dev/null ; then
      eval `$BIN/getconfig.sh sh`
      case "$PROGRAM" in
        RISTTx) start_tx ;;
             *) start_rx ;;
      esac
      sleep 2
    fi
    $BIN/started.sh set 1
    $BIN/getstate.sh
    ;;
  stop)
    if pidof $PROGRAM > /dev/null ; then
      case "$PROGRAM" in
        RISTTx) stop_tx ;;
             *) stop_rx ;;
      esac
      sleep 2
    fi
    $BIN/started.sh set 0
    $BIN/getstate.sh
    ;;
  reset)
    reset_proxy
    ;;
  status)
    proxy_running
    ;;
esac
