#!/bin/sh

INSTALL_DIR=/disk/RIST
BACKUP_DIR=/tmp/backup$$
UPDATE_FILE=QVProRIST.tar.gz
CONFIG_FILE=share/snmp/snmpd.conf
PROXY_CONTROL=$INSTALL_DIR/controlproxy.sh
TUN_CONTROL=$INSTALL_DIR/controltun.sh

[ ! -f $PROXY_CONTROL ] && PROXY_CONTROL=
[ ! -f $TUN_CONTROL ] && TUN_CONTROL=

# Stop proxy
PROXY_STARTED=0
if [ "$PROXY_CONTROL" != "" ] ; then
    if $PROXY_CONTROL status ; then
        PROXY_STARTED=1
        echo 'Stopping RIST Proxy<br>'
        $PROXY_CONTROL stop > /dev/null
    fi
fi

# Stop tunnel
TUN_STARTED=0
if [ "$TUN_CONTROL" != "" ] ; then
    if $TUN_CONTROL status ; then
        TUN_STARTED=1
        echo 'Stopping RIST Tunnel<br>'
        $TUN_CONTROL stop > /dev/null
    fi
fi

# Create backup directory
mkdir $BACKUP_DIR

# Backup files
FILE=$INSTALL_DIR/proxy_db
[ -f $FILE ] && cp $FILE $BACKUP_DIR
sync

# Clean install directory
rm -rf $INSTALL_DIR
sync

# Install new software
tar xf /tmp/$UPDATE_FILE -C /disk
sync

# Restore saved files
FILE=$BACKUP_DIR/proxy_db
[ -f $FILE ] && cp $FILE $INSTALL_DIR
sync

# Delete backup directory
rm -rf $BACKUP_DIR

# Setup rc.extra
$INSTALL_DIR/update_rc_extra.sh

# Run rc.rist
sh -x $INSTALL_DIR/rc.rist > /tmp/rc.rist.log 2>&1

# Start tunnel if not started by rc.rist
if [ $TUN_STARTED = 1 ] ; then
    if ! $TUN_CONTROL status ; then
        echo 'Starting RIST Tunnel<br>'
        $TUN_CONTROL start > /dev/null
    fi
fi

# Start proxy if not started by rc.rist
if [ $PROXY_STARTED = 1 ] ; then
    if ! $PROXY_CONTROL status ; then
        echo 'Starting RIST Proxy<br>'
        $PROXY_CONTROL start > /dev/null
    fi
fi

# Cleanup files
rm -f $UPDATE_FILE script.sh install.sh
sync

echo 'Click <a href="/cgi-bin/tun.cgi" target=_blank>HERE</a> to start Tunnel GUI <br>'
echo 'Click <a href="/cgi-bin/rist.cgi" target=_blank>HERE</a> to start Proxy GUI'
exit 0
